@@ -13,7 +13,7 @@ neotermcolor.readline_always_safe = True
 from .sharedobj import common, current_command
 from .tools import print_tb, err
 from .compl import ComplOID, ComplSvc, ComplDbSvc, ComplNode, ComplYamlFile
-from .compl import ComplOIDtp, ComplSvcRpcMethod, ComplSvcRpcParams
+from .compl import ComplOIDtp, ComplSvcRpcMethod, ComplSvcRpcParams, ComplEdit
 from .client import call_rpc
 
 DEFAULT_RPC_ERROR_MESSAGE = {
@@ -53,7 +53,7 @@ def dispatcher(_command,
             print_tb(force=True)
     except Exception as e:
         current_command.exit_code = 1
-        err(e)
+        err(f'{e.__class__.__name__}: {e}')
         if current_command.debug:
             print_tb(force=True)
     current_command.debug = False
@@ -254,8 +254,8 @@ def append_svc_cli(root_sp):
     p = sp.add_parser('destroy', help='destroy service')
     p.add_argument('i', metavar='SVC').completer = ComplSvc()
 
-    p = sp.add_parser('purge',
-                      help='purge service (destroy and delete configs)')
+    p = sp.add_parser(
+        'purge', help='purge service (destroy and delete all service data)')
     p.add_argument('i', metavar='SVC').completer = ComplSvc()
 
 
@@ -265,15 +265,22 @@ def append_item_cli(root_sp):
                            metavar='SUBCOMMAND',
                            help='sub command')
 
+    p = sp.add_parser(
+        'announce',
+        help='forcibly announce current item states via the local bus')
+    p.add_argument('i', metavar='MASK').completer = ComplOID('state')
+    p.add_argument('-n', metavar='NODE').completer = ComplNode()
+
     p = sp.add_parser('list', help='list items')
     p.add_argument('i', metavar='MASK').completer = ComplOID()
     p.add_argument('-n', metavar='NODE').completer = ComplNode()
 
     p = sp.add_parser('state', help='item states')
-    p.add_argument('i', metavar='MASK').completer = ComplOID()
+    p.add_argument('i', metavar='MASK').completer = ComplOID('state')
+    p.add_argument('-y', '--full', action='store_true')
 
     p = sp.add_parser('history', help='item state history')
-    p.add_argument('i', metavar='OID').completer = ComplOID()
+    p.add_argument('i', metavar='OID').completer = ComplOID('state')
     p.add_argument('-a',
                    '--db-svc',
                    help='database service',
@@ -361,6 +368,27 @@ def append_item_cli(root_sp):
     p.add_argument('-f', '--file', metavar='FILE',
                    help='deployment file').completer = ComplYamlFile()
 
+    p = sp.add_parser('watch', help='Watch item state')
+    p.add_argument('i', metavar='OID').completer = ComplOID()
+    p.add_argument('-n',
+                   '--interval',
+                   help='Watch interval (default: 1s)',
+                   metavar='SEC',
+                   default=1,
+                   type=float)
+    p.add_argument('-r', '--rows', help='Rows to plot', metavar='NUM', type=int)
+    p.add_argument('-x',
+                   '--prop',
+                   help='State prop to use (default: value)',
+                   choices=['status', 'value'],
+                   metavar='PROP',
+                   default='value')
+    p.add_argument('-p',
+                   '--chart-type',
+                   help='Chart type',
+                   choices=['bar', 'line'],
+                   default='bar')
+
 
 def append_lvar_cli(root_sp):
     ap = root_sp.add_parser('lvar', help='lvar commands')
@@ -449,6 +477,7 @@ def sys_cmd(cmd):
         print('Executing system shell')
         sh_cmd = os.getenv('SHELL')
         if sh_cmd is None:
+            import distutils.spawn
             sh_cmd = distutils.spawn.find_executable('bash')
             if not sh_cmd:
                 sh_cmd = 'sh'
@@ -480,7 +509,7 @@ def init_ap():
 
     ap.add_argument('-D',
                     '--debug',
-                    help='debug ELBUS call',
+                    help='debug the bus call',
                     action='store_true')
     ap.add_argument('-J', '--json', help='JSON output', action='store_true')
     ap.add_argument('-T',
@@ -504,18 +533,18 @@ def init_ap():
     append_svc_cli(sp)
     sp.add_parser('test', help='core test/info')
 
-    p = sp.add_parser('edit', help='edit the configuration keys')
-    p.add_argument('config',
-                   metavar='CONFIG',
-                   help='config key to edit',
-                   choices=[
-                       'config/core', 'config/elbus', 'config/logs',
-                       'config/python-venv', 'config/registry'
-                   ])
+    p = sp.add_parser('edit', help='edit the configuration keys and xc files')
+    p.add_argument(
+        'fname',
+        metavar='CONFIG',
+        help='config key to edit',
+    ).completer = ComplEdit()
     p.add_argument(
         '--offline',
         action='store_true',
-        help='connect directly to the registry db when the node is offline')
+        help=
+        'for keys: connect directly to the registry db when the node is offline'
+    )
 
     try:
         import requests
@@ -537,7 +566,7 @@ def init_ap():
             help='do not perform the actual update, get the info only')
         p.add_argument('--test',
                        action='store_true',
-                       help='install the build marked as test')
+                       help='install a build marked as test')
     except ModuleNotFoundError:
         pass
 
