@@ -9,7 +9,7 @@ from rapidtables import format_table, FORMAT_GENERATOR, FORMAT_GENERATOR_COLS
 
 from .tools import print_result, ok, edit_config, read_file, err
 from .tools import print_action_result, format_value, prepare_time
-from .tools import get_node_svc_info
+from .tools import get_node_svc_info, edit_file, get_term_size
 from .client import call_rpc
 from .sharedobj import common, current_command
 
@@ -125,7 +125,8 @@ class CLI:
             if build == new_build:
                 return
             if build > new_build:
-                raise RuntimeError('Your build is newer than update server has')
+                raise RuntimeError(
+                    'Your build is newer than then update server has')
             manifest = json.loads(
                 safe_download(f'{repository_url}/{new_version}/nightly/'
                               f'manifest-{new_build}.json'))
@@ -205,13 +206,16 @@ class CLI:
             cmd += ' --offline'
         os.system(cmd)
 
-    def edit(self, config, offline=False):
-        cmd = f'{common.dir_eva}/bin/eva-registry'
-        if offline:
-            cmd += ' --offline'
-        cmd += f' edit eva/"{config}"'
-        if not os.system(cmd) and config != 'config/python-venv':
-            print('restart or reload the node server to apply changes')
+    def edit(self, fname, offline=False):
+        if fname.startswith('config'):
+            cmd = f'{common.dir_eva}/bin/eva-registry'
+            if offline:
+                cmd += ' --offline'
+            cmd += f' edit eva/"{fname}"'
+            if not os.system(cmd) and fname != 'config/python-venv':
+                print('restart or reload the node server to apply changes')
+        else:
+            edit_file(fname)
 
     def log_purge(self):
         call_rpc('log.purge')
@@ -230,10 +234,12 @@ class CLI:
                 return dict(color='red')
             return {}
 
+        width, height = get_term_size()
+
         params = {
             'level': level,
             'time': time,
-            'limit': limit,
+            'limit': limit if limit else height - 3,
             'module': module,
             'rx': regex
         }
@@ -248,23 +254,27 @@ class CLI:
                          host=r['h'],
                          module=r['mod'],
                          level=r['lvl'].upper(),
-                         message=r['msg'] if full else r['msg'][:55]))
+                         message=r['msg']))
             header, rows = format_table(data, fmt=FORMAT_GENERATOR)
+            if not full:
+                header = header[:width]
             print(colored(header, color='blue'))
             print(colored('-' * len(header), color='grey'))
             for row, record in zip(rows, data):
-                print(colored(row, **log_record_color(record['level'])))
+                print(
+                    colored(row if full else row[:width],
+                            **log_record_color(record['level'])))
 
     def svc_list(self):
         data = call_rpc('svc.list')
-        print_result(data, cols=['name', 'status', 'pid', 'launcher'])
+        print_result(data, cols=['id', 'status', 'pid', 'launcher'])
 
     def svc_export(self, i, output=None):
         import yaml
         c = 0
         configs = []
         for svc in call_rpc('svc.list'):
-            name = svc['name']
+            name = svc['id']
             if (i.startswith('*') and name.endswith(i[1:])) or \
                 (i.endswith('*') and name.startswith(i[:-1])) or \
                 (i.startswith('*') and i.endswith('*') and i[1:-1] in name) or \
@@ -439,11 +449,11 @@ class CLI:
     def action_terminate(self, u):
         import uuid
         call_rpc('action.terminate', dict(u=uuid.UUID(u).bytes))
-        ok(())
+        ok()
 
     def action_kill(self, i):
         call_rpc('action.kill', dict(i=i))
-        ok(())
+        ok()
 
     def action_result(self, u):
         import uuid
@@ -535,6 +545,13 @@ class CLI:
                          'node', 'connected', 'enabled'
                      ])
 
+    def item_announce(self, i, n=None):
+        data = call_rpc(
+            'item.announce',
+            dict(i=i, node=n),
+        )
+        ok()
+
     def item_export(self, i, output=None):
         import yaml
         c = 0
@@ -614,15 +631,15 @@ class CLI:
         call_rpc('item.disable', dict(i=i))
         ok()
 
-    def item_state(self, i):
+    def item_state(self, i, full):
         data = call_rpc(
             'item.state',
-            dict(i=i),
+            dict(i=i, full=full),
         )
         print_result(data,
                      cols=[
                          'oid', 'status', 'value', 'ieid',
-                         't|n=set time|f=time', 'node', 'connected'
+                         't|n=set time|f=time', 'node', 'connected', 'act'
                      ])
 
     def item_slog(self, i, db_svc, time_start, time_end, time_zone, limit):
@@ -669,6 +686,109 @@ class CLI:
         ]
         print_result(data, cols=cols)
 
+    def item_watch(self, i, interval, rows, prop, chart_type):
+        from . import charts
+        import datetime
+        vals = []
+        to_clear = 0
+        old_width = 0
+        old_height = 0
+        limit = rows
+        limit_auto_set = rows is None
+
+        def _append(label, value, limit):
+            if chart_type == 'bar':
+                vals.append((label, value))
+            else:
+                if isinstance(value, float):
+                    vals.append(value)
+                else:
+                    try:
+                        v = float(value)
+                    except:
+                        v = 0
+                    vals.append(v)
+            while len(vals) > limit:
+                vals.pop(0)
+
+        next_step = time.perf_counter() + interval
+        try:
+            while True:
+                if chart_type == 'bar':
+                    label = datetime.datetime.now().strftime('%T.%f')[:-5]
+                else:
+                    label = datetime.datetime.now().isoformat()
+                width, height = get_term_size()
+                if limit is None:
+                    if chart_type == 'bar':
+                        limit = height - 2
+                    else:
+                        limit = width - 12
+                if width != old_width or height != old_height:
+                    os.system('clear')
+                    if chart_type == 'bar':
+                        print(colored(i, color='yellow'))
+                    old_width, old_height = width, height
+                    if limit_auto_set:
+                        if chart_type == 'bar':
+                            limit = height - 2
+                        else:
+                            rows = height - 6
+                elif chart_type == 'bar':
+                    for t in range(to_clear):
+                        sys.stdout.write('\033[F\033[K')
+                elif chart_type == 'line':
+                    os.system('clear')
+                res = call_rpc('item.state', dict(i=i))
+                for data in res:
+                    if data['oid'] == i:
+                        break
+                else:
+                    raise ValueError('no state returned')
+                v = data.get(prop)
+                if isinstance(v, str):
+                    try:
+                        v = int(v)
+                    except:
+                        try:
+                            v = float(v)
+                        except:
+                            v = None
+                if chart_type == 'bar':
+                    _append(label, v, limit)
+                    charts.plot_bar_chart(vals)
+                    to_clear = len(vals)
+                else:
+                    _append(label, v, width)
+                    max_value_width = 0
+                    for z in vals:
+                        x = len(str(z))
+                        if x > max_value_width:
+                            max_value_width = x
+                    while len(vals) > width - (max_value_width if
+                                               max_value_width > 7 else 7) - 5:
+                        vals.pop(0)
+                    max_value_width += 2
+                    print(
+                        f'{colored(i, color="yellow")} '
+                        f'{colored(label, color="cyan")}: ',
+                        end='')
+                    if v is None:
+                        print(colored('NaN', color='magenta'))
+                    else:
+                        print(colored(v, color='green', attrs='bold'))
+                    charts.plot_line_chart(vals, rows, max_value_width)
+                t = time.perf_counter()
+                sleep_to = next_step - t
+                if sleep_to > 0:
+                    time.sleep(sleep_to)
+                    next_step += interval
+                else:
+                    next_step = t
+        except KeyboardInterrupt:
+            return
+        pass
+
     def lvar_set(self, i, status, value):
         params = dict(i=i)
         if status is not None:
