@@ -27,7 +27,8 @@ def err(e, delay=False):
     print(colored(str(e), color='red'))
     if delay:
         import getch
-        getch.getch()
+        if getch.getch() == '\x03':
+            raise KeyboardInterrupt
 
 
 def prepare_time(t):
@@ -48,7 +49,8 @@ def print_tb(force=False, delay=False):
         err('FAILED')
     if delay:
         import getch
-        getch.getch()
+        if getch.getch() == '\x03':
+            raise KeyboardInterrupt
 
 
 def can_colorize():
@@ -131,10 +133,10 @@ def print_action_result(result):
             print(colored(r[1], color=ACTION_STATUS_COLOR.get(status)))
         else:
             print(r[1])
-    if out:
+    if out is not None:
         print('--- OUT ---')
         print(out)
-    if err:
+    if err is not None:
         print('--- ERR ---')
         print(colored(err, color='red'))
     print()
@@ -214,6 +216,8 @@ def print_result(data, need_header=True, name_value=False, cols=None):
                 header, rows = format_table(formatted_data,
                                             fmt=FORMAT_GENERATOR)
             else:
+                if data and not isinstance(data[0], dict):
+                    data = [{'value': d} for d in data]
                 header, rows = format_table(data, fmt=FORMAT_GENERATOR)
             if need_header:
                 print(colored(header, color='blue'))
@@ -223,6 +227,34 @@ def print_result(data, need_header=True, name_value=False, cols=None):
     print()
 
 
+def edit_file(fname):
+    from pathlib import Path
+    suffix = Path(fname).suffix
+    fname = f'{common.dir_eva}/{fname}'
+    editor = os.getenv('EDITOR', 'vi')
+    while True:
+        code = os.system(f'{editor} "{fname}"')
+        if code:
+            err(f'editor exited with code {code}')
+            break
+        try:
+            if suffix in ['.yaml', '.yml']:
+                import yaml
+                with open(fname) as fh:
+                    yaml.safe_load(fh.read())
+            elif suffix == '.json':
+                import json
+                with open(fname) as fh:
+                    json.loads(fh.read())
+            elif suffix == '.py':
+                with open(fname) as fh:
+                    compile(fh.read(), fname, 'exec')
+            break
+        except:
+            print_tb(force=True, delay=True)
+            continue
+
+
 def edit_config(value, ss, deploy_fn, initial=False):
     import yaml
     import tempfile
@@ -293,6 +325,19 @@ def format_value(value, advanced=False):
                 return value
 
 
+def safe_print(val, extra=0):
+    width, height = get_term_size()
+    print(val[:width + extra])
+
+
+def get_term_size():
+    width, height = os.get_terminal_size(0)
+    if width == 0 or height == 0:
+        return (80, 25)
+    else:
+        return (width, height)
+
+
 def get_node_svc_info():
     import json
     return json.loads(
